@@ -10,10 +10,9 @@
   packageStartupMessage(paste0(
          " If you benefit from this package, please cite:\n",
          " \n",
-         " Zhang, Jie & Huang, Kun (2014) \n",
-         " Normalized ImQCM: An Algorithm for Detecting Weak Quasi-Cliques\n",
-         " in Weighted Graph with Applications in Gene Co-Expression Module\n",
-         " Discovery in Cancers. Cancer informatics, 13, CIN-S14021.\n"))
+         "Huang Z, Han Z, Wang T, Shao W, Xiang S, Salama P, Rizkalla M, Huang K, Zhang J.\n",
+         "TSUNAMI: Translational Bioinformatics Tool Suite For Network Analysis And Mining.\n",
+         "bioRxiv. 2019 Jan 1:787507.\n"))
   packageStartupMessage("==========================================================================\n\n");
 }
 
